Welcome to Orange3 Bioinformatics Documentation
================================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/databasesupdate
   widgets/geodatasets
   widgets/dictyExpress
   widgets/differentialexpression
   widgets/geneinfo
   widgets/gobrowser
   widgets/keggpathways


Scripting Reference
-------------------

.. toctree::
   :maxdepth: 1

   scripting_references/ncbi_taxonomy
   scripting_references/ncbi_gene
   scripting_references/resolwe